@@ -4,3 +4,9 @@ from .pyfiguration import PyFiguration
 
 # Create an instance of PyFiguration
 conf = PyFiguration()
+
+__all__ = [
+    "cli",
+    "PyFiguration",
+    "conf",
+]
